<?php

	/**
	 * Dieser Service stellt eine Server2Server-Schnittstelle (API), zur Buchung von Transaktionen ber die Zahlungsart Kreditkarte, zur Verfgung (Creditcard - API.Event).
	 * 
	 *   Vorraussetzungen:
	 *  - Ein Account bei micropayment - Anmeldung unter www.micropayment.de
	 *  - Die Freischaltung von Creditcard - API.Event durch unseren Hndler-Support (support@micropayment.de)
	 *  - Eine Vertrags-Unternehmennummer (VU-Nummer) die Sie im ControlCenter beantragen knnen
	 * 
	 *  Konfiguration:
	 *  Nach der Freischaltung von Creditcard - API.Event durch unseren Support loggen Sie sich in das ControlCenter Ihres Accounts ein und begeben sich zu dem Menpunkt "Meine Konfiguration":
	 *  - hier finden Sie im unteren Bereich den `AccessKey` den Sie fr die Verwendung des API bentigen
	 *  - im Untermenpunkt "APIs" konfigurien und aktivieren Sie Creditcard - API.Event
	 *  - im Untermenpunkt "Zugriffsberechtigungen" konfigurieren Sie bitte die IP-Adresse/IP-Range der Server, von dem aus Sie auf das API zugreifen mchten
	 * 
	 *  Hinweis zu Hoch-Traffic-Anwendungen:
	 *  Grundstzlich kann ein Kreditkartenterminal immer nur eine Buchung zur selben Zeit ausfhren.
	 *  Bei normalem Traffic fngt eine Warteschlange gleichzeitige Anfragen auf.
	 *  Wenn aber parallele Transaktionen erforderlich sind (z.B. bei Trafficspitzen), knnen Sie zur Lastverteilung bei unserem Support zustzliche Terminals ordern.
	 * 
	 *  Hinweise zum TestModus:
	 *  - Aktivierung der Testumgebung erfolgt in der jeweiligen Funktion ber den Parameter `testMode`
	 *  - fr den TestModus stehen folgende Test-Kartennummern zur Verfgung:
	 * 	- VISA: 4111111111111111
	 * 	- MASTER: 5454545454545454
	 * 	- AMEX: 343434343434343
	 *  - um erfolgreiche Buchungen durchzufhren, ist als CVC2-Code die 666 zu verwenden, bei allen Anderen gilt die Transaktion als fehlgeschlagen
	 *  - um einen spezifischen Terminal-Fehlercode auszulsen, ist als CVC2-Code die 555 zu verwenden:
	 *    Der als Integerwert (bspw. 534) angefordertete Endkundenbetrag liefert im Eurocent-Anteil (bspw. 34) den Fehlercode (`transactionResultCode`) zurck - z.B. 534 => ipg34.
	 *  	 Bitte beachten Sie, dass das erwartete Ergebnis nur bei der Verwendung der Whrung (`currency`) "EUR" erreicht wird.
	 * 
	 *  bermittlung von Adressdaten:
	 *  Sollten Ihnen die Adressdaten Ihrer Endkunden zur Verfgung stehen, empfehlen wir diese mittles "addressSet" im Kundendatensatz zu hinterlegen.
	 *  Die im Kundendatensatz (customerCreate, customerSet) hinterlegten Adressdaten, werden zum Einen fr das Adress-Verifikations-System (AVS, verfgbar ab Version 1.5) bentigt,
	 *  zum Anderen werden diese Daten bei Chargeback-Anfragen (s.g. Beleganforderungen von Issuer und Acquirerer) verwendet.
	 * 
	 *  Fehlercodes:
	 *  Eine bersicht ber die mglichen Fehlercodes des API als auch des Terminals finden Sie unter folgender Adresse:
	 *  https://sipg.micropayment.de/public/creditcard/ERRORCODES/
	 * 
	 *  Updates/Changelog:
	 *  Wenn Sie bisher eine ltere Version dieses APIs verwenden, knnten Sie sich im Changelog einen berblick ber die Neuerungen verschaffen:
	 *  https://sipg.micropayment.de/public/creditcard/CHANGELOG/
	 *
	 * @copyright 2016 micropayment GmbH
	 * @link http://www.micropayment.de/
	 * @author Yves Berkholz, Guido Franke
	 * @version 1.6
	 * @created 2016-12-07 18:57:27
	 */
	interface IMcpCreditcardService_v1_6 {

		/**
		 * Gibt Informationen ber eine Transaktion anhand einer verschlsselten Transaktionsnummer zurck. Diese ensteht bei der Tokenisation mit der JsBridge.
		 * 
		 *  Wenn sich `currencyInit` und `currencyBooked` unterscheiden, dann fehlt die native Untersttzung fr die gewnschte Whrung.
		 *  In diesem Fall erfolgte eine Umrechnung in eine nativ untersttzte Whrung.
		 *  Die verschlsselte Transaktionsnummer, $cryptId, wird an die Rcksprungadresse nach dem Zahlvorgang angehngt, siehe IFrameScript Billingfunktionen.
		 *  Fr die weiteren Abfragen etc. nutzten Sie bitte die Transaktionsnummer, $transactionId, aus dem Response, da die $cryptId ca. 2 Stunden nach
		 *  der Erstellung ungltig wird!
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $cryptId verschlsselte Transaktionsnummer
		 * 
		 * @return struct 
		 * @result string $transactionId Transaktionsnummer
		 * @result string $sessionId eindeutige ID des Vorgangs
		 * @result string $customerId ID des Kunden
		 * @result string $auth AuthCode
		 * @result integer $amountInit Betrag der abgerechnet werden sollte in currencyInit
		 * @result string $currencyInit Whrungseinheit mit der abgerechnet werden sollte
		 * @result integer $amountBooked gebuchter Betrag in currencyBooked
		 * @result string $currencyBooked Whrungseinheit mit der gebucht wurde
		 * @result integer $amountInternal abgerechneter Betrag in currencyInternal
		 * @result string $currencyInternal (default='EUR')  Whrungseinheit fr interne Verbuchung
		 * @result TransactionType $type Art der Transaktion
		 * @result TransactionStatus $status Status der Transaktion
		 * @result datetime $created Zeitpunkt der Transaktion
		 * @result string $ip IPv4 des Benutzers
		 * @result string $cardType (default=null)  Kartentyp, kann bei aktiviertem DataStorage-Feature null sein
		 * @result string $cardNumber (default=null)  partielle Kreditkartennummer [letzten 4 Stellen], kann bei aktiviertem DataStorage-Feature null sein
		 * @result integer $cardExpiryYear (default=null)  Gltigkeits Jahr, kann bei aktiviertem DataStorage-Feature null sein
		 * @result integer $cardExpiryMonth (default=null) 	Gltigkeits Monat, kann bei aktiviertem DataStorage-Feature null sein
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 * @result AVSResult $avsResult (default=null)  Wenn ein AVS-Check durchgefhrt wurde dessen Ergebnis
		 */
		public function transactionGetCrypt($accessKey, $testMode=0, $cryptId);

		/**
		 * Erstellt einen neuen Kunden und verknpft Kreditkartendaten.
		 *  Entspricht der Kombination aus 'customerCreate' und 'creditCardDataSet', wobei die bentigten Daten aus dem token generiert werden.
		 *  Der token wird bei der Tokenisation ber das IFrameScript erzeugt.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $token (default=null)  Token. Wird bei der IFramelsung erstellt.
		 * @param string $firstname (default=null)  Vorname des Kunden
		 * @param string $surname (default=null)  Nachname des Kunde
		 * @param integer $doublet (default=1)  Dublette erlauben, d.h. eine Kreditkartennummer kann von mehreren Customern verwendet werden. Wenn 0, dann scheitert die Funktion, siehe code 4105
		 * @param string $email (default=null)  E-Mail-Adresse des Kunden, wenn nach den Transaktionen einen E-Mail an der Kunden versand werden soll
		 * @param string $culture (default='de-DE')  Sprache & Land des Kunden | gltige Beispielwerte sind 'de', 'de-DE', 'en-US'
		 * @param string $customerId (default=null)  eigene eindeutige ID des Kunden, wird anderenfalls erzeugt [min./max. Zeichen 10/40, alphanumerisch]
		 * @param map $freeParams (default=null)  Liste mit freien Parametern, die dem Kunden zugeordnet werden
		 * @param integer $update (default=0)  bei bestehendem Customer: 0=error, 1=update aller Parameter, 2=update nur von gesetzten Parametern
		 * 
		 * @return struct 
		 * @result string $customerId eigene oder erzeugte eindeutige ID des Kunden
		 * @result boolean $cvc2Required gibt Auskunft darber, ob bei der nchsten Buchung der CVC2-Code erforderlich ist
		 */
		public function tokenCustomerCreate($accessKey, $testMode=0, $token=null, $firstname=null, $surname=null, $doublet=1, $email=null, $culture='de-DE', $customerId=null, $freeParams=null, $update=0);

		/**
		 * Erzeugt einen neuen Bezahlvorgang fr einen Kunden. Der Kunde und die Session werden angelegt.
		 *  Kombiniert die Funktionen 'tokenCustomerCreate', und 'sessionCreate'
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $token (default=null)  Token. Wird bei der IFramelsung erstellt.
		 * @param string $firstname (default=null)  Vorname des Kunden
		 * @param string $surname (default=null)  Nachname des Kunde
		 * @param integer $doublet (default=1)  Dublette erlauben, d.h. eine Kreditkartennummer kann von mehreren Customern verwendet werden. Wenn 0, dann scheitert die Funktion, siehe code 4105
		 * @param string $email (default=null)  E-Mail-Adresse des Kunden, wenn nach den Transaktionen einen E-Mail an der Kunden versand werden soll
		 * @param string $culture (default='de-DE')  Sprache & Land des Kunden | gltige Beispielwerte sind 'de', 'de-DE', 'en-US'
		 * @param string $customerId (default=null)  eigene eindeutige ID des Kunden, wird anderenfalls erzeugt [min./max. Zeichen 10/40, alphanumerisch]
		 * @param map $freeParams (default=null)  Liste mit freien Parametern, die dem Kunden zugeordnet werden
		 * @param string $project das Projektkrzel fr den Vorgang
		 * @param string $projectCampaign (default=null)  ein Kampagnenkrzel des Projektbetreibers
		 * @param string $account (default=null)  Account des beteiligten Webmasters sonst eigener - setzt eine Aktivierung der Webmasterfhigkeit des Projekts vorraus - Hinweis: Webmasterfhigkeit steht momentan nicht zur Verfgung
		 * @param string $webmasterCampaign (default=null)  ein Kampagnenkrzel des Webmasters
		 * @param integer $amount (default=null)  abzurechnender Betrag, wird kein Betrag bergeben, wird der Betrag aus der Konfiguration verwendet
		 * @param string $currency (default='EUR')  Whrung
		 * @param string $title (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung in Falle einer auftretenden Benachrichtigung wird dieser Wert als Produktidentifizierung mit geschickt, wird kein Wert bergeben, wird Der aus der Konfiguration verwendet
		 * @param string $paytext (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung beim Mailversand, sollten Sie Diesen wnschen
		 * @param string $ip IPv4 des Benutzers
		 * @param boolean $sendMail (default=true) 
		 * @param map $freeParamsSession (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @param string $sessionId (default=null)  eigene eindeutige ID des Vorgangs, wird anderenfalls erzeugt [max. 40 Zeichen]
		 * @param integer $update (default=0)  bei bestehendem Customer: 0=error, 1=update aller Parameter, 2=update nur von gesetzten Parametern
		 * 
		 * @return struct 
		 * @result string $customerId eigene oder erzeugte eindeutige ID des Kunden
		 * @result boolean $cvc2Required gibt Auskunft darber, ob bei der nchsten Buchung der CVC2-Code erforderlich ist
		 * @result string $sessionId eigene oder erzeugte eindeutige ID des Vorgangs
		 * @result SessionStatus $status Vorgangsstatus "INIT"
		 * @result datetime $expire Ablaufzeit des Vorgangs
		 */
		public function tokenSessionCreate($accessKey, $testMode=0, $token=null, $firstname=null, $surname=null, $doublet=1, $email=null, $culture='de-DE', $customerId=null, $freeParams=null, $project, $projectCampaign=null, $account=null, $webmasterCampaign=null, $amount=null, $currency='EUR', $title=null, $paytext=null, $ip, $sendMail=true, $freeParamsSession=null, $sessionId=null, $update=0);

		/**
		 * sofortige Buchung
		 *  Kombiniert die Funktionen 'customerCreate', 'creditCardDataSet', 'sessionCreate' und 'transactionPurchase'
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $token (default=null)  Token. Wird bei der IFramelsung erstellt.
		 * @param string $firstname (default=null)  Vorname des Kunden
		 * @param string $surname (default=null)  Nachname des Kunde
		 * @param integer $doublet (default=1)  Dublette erlauben, d.h. eine Kreditkartennummer kann von mehreren Customern verwendet werden. Wenn 0, dann scheitert die Funktion, siehe code 4105
		 * @param string $email (default=null)  E-Mail-Adresse des Kunden, wenn nach den Transaktionen einen E-Mail an der Kunden versand werden soll
		 * @param string $culture (default='de-DE')  Sprache & Land des Kunden | gltige Beispielwerte sind 'de', 'de-DE', 'en-US'
		 * @param string $customerId (default=null)  eigene eindeutige ID des Kunden, wird anderenfalls erzeugt [min./max. Zeichen 10/40, alphanumerisch]
		 * @param map $freeParams (default=null)  Liste mit freien Parametern, die dem Kunden zugeordnet werden
		 * @param string $project das Projektkrzel fr den Vorgang
		 * @param string $projectCampaign (default=null)  ein Kampagnenkrzel des Projektbetreibers
		 * @param string $account (default=null)  Account des beteiligten Webmasters sonst eigener - setzt eine Aktivierung der Webmasterfhigkeit des Projekts vorraus - Hinweis: Webmasterfhigkeit steht momentan nicht zur Verfgung
		 * @param string $webmasterCampaign (default=null)  ein Kampagnenkrzel des Webmasters
		 * @param integer $amount (default=null)  abzurechnender Betrag, wird kein Betrag bergeben, wird der Betrag aus der Konfiguration verwendet
		 * @param string $currency (default='EUR')  Whrung
		 * @param string $title (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung in Falle einer auftretenden Benachrichtigung wird dieser Wert als Produktidentifizierung mit geschickt, wird kein Wert bergeben, wird Der aus der Konfiguration verwendet
		 * @param string $paytext (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung beim Mailversand, sollten Sie Diesen wnschen
		 * @param string $ip IPv4 des Benutzers
		 * @param boolean $sendMail (default=true) 
		 * @param map $freeParamsSession (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @param string $sessionId (default=null)  eigene eindeutige ID des Vorgangs, wird anderenfalls erzeugt [max. 40 Zeichen]
		 * @param string $cvc2 (default=null)  CVC2-Code der Kreditkarte, mu min einmal pro Kreditkarte/Verfallszeit angegeben worden sein
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * @param integer $avsCheck (default=0)  de/aktiviert das AddressVerificationSystem
		 * @param integer $update (default=0)  bei bestehendem Customer: 0=error, 1=update aller Parameter, 2=update nur von gesetzten Parametern
		 * 
		 * @return struct 
		 * @result string $customerId eigene oder erzeugte eindeutige ID des Kunden
		 * @result string $sessionId eigene oder erzeugte eindeutige ID des Vorgangs
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 * @result AVSResult $avsResult (default=null)  wenn ein AVS-Check angefordert wurde dessen Ergebnis
		 */
		public function tokenPurchase($accessKey, $testMode=0, $token=null, $firstname=null, $surname=null, $doublet=1, $email=null, $culture='de-DE', $customerId=null, $freeParams=null, $project, $projectCampaign=null, $account=null, $webmasterCampaign=null, $amount=null, $currency='EUR', $title=null, $paytext=null, $ip, $sendMail=true, $freeParamsSession=null, $sessionId=null, $cvc2=null, $fraudDetection=1, $avsCheck=0, $update=0);

		/**
		 * sofortige Vorautorisierung
		 *  Kombiniert die Funktionen 'customerCreate', 'creditCardDataSet', 'sessionCreate' und 'transactionAuthorization'
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $token (default=null)  Token. Wird bei der IFramelsung erstellt.
		 * @param string $firstname (default=null)  Vorname des Kunden
		 * @param string $surname (default=null)  Nachname des Kunde
		 * @param integer $doublet (default=1)  Dublette erlauben, d.h. eine Kreditkartennummer kann von mehreren Customern verwendet werden. Wenn 0, dann scheitert die Funktion, siehe code 4105
		 * @param string $email (default=null)  E-Mail-Adresse des Kunden, wenn nach den Transaktionen einen E-Mail an der Kunden versand werden soll
		 * @param string $culture (default='de-DE')  Sprache & Land des Kunden | gltige Beispielwerte sind 'de', 'de-DE', 'en-US'
		 * @param string $customerId (default=null)  eigene eindeutige ID des Kunden, wird anderenfalls erzeugt [min./max. Zeichen 10/40, alphanumerisch]
		 * @param map $freeParams (default=null)  Liste mit freien Parametern, die dem Kunden zugeordnet werden
		 * @param string $project das Projektkrzel fr den Vorgang
		 * @param string $projectCampaign (default=null)  ein Kampagnenkrzel des Projektbetreibers
		 * @param string $account (default=null)  Account des beteiligten Webmasters sonst eigener - setzt eine Aktivierung der Webmasterfhigkeit des Projekts vorraus - Hinweis: Webmasterfhigkeit steht momentan nicht zur Verfgung
		 * @param string $webmasterCampaign (default=null)  ein Kampagnenkrzel des Webmasters
		 * @param integer $amount (default=null)  abzurechnender Betrag, wird kein Betrag bergeben, wird der Betrag aus der Konfiguration verwendet
		 * @param string $currency (default='EUR')  Whrung
		 * @param string $title (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung in Falle einer auftretenden Benachrichtigung wird dieser Wert als Produktidentifizierung mit geschickt, wird kein Wert bergeben, wird Der aus der Konfiguration verwendet
		 * @param string $paytext (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung beim Mailversand, sollten Sie Diesen wnschen
		 * @param string $ip IPv4 des Benutzers
		 * @param boolean $sendMail (default=true) 
		 * @param map $freeParamsSession (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @param string $sessionId (default=null)  eigene eindeutige ID des Vorgangs, wird anderenfalls erzeugt [max. 40 Zeichen]
		 * @param string $cvc2 (default=null)  CVC2-Code der Kreditkarte, mu min einmal pro Kreditkarte/Verfallszeit angegeben worden sein
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * @param integer $avsCheck (default=0)  de/aktiviert das AddressVerificationSystem
		 * @param integer $update (default=0)  bei bestehendem Customer: 0=error, 1=update aller Parameter, 2=update nur von gesetzten Parametern
		 * 
		 * @return struct 
		 * @result string $customerId eigene oder erzeugte eindeutige ID des Kunden
		 * @result string $sessionId eigene oder erzeugte eindeutige ID des Vorgangs
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 * @result AVSResult $avsResult (default=null)  wenn ein AVS-Check angefordert wurde dessen Ergebnis
		 */
		public function tokenAuthorization($accessKey, $testMode=0, $token=null, $firstname=null, $surname=null, $doublet=1, $email=null, $culture='de-DE', $customerId=null, $freeParams=null, $project, $projectCampaign=null, $account=null, $webmasterCampaign=null, $amount=null, $currency='EUR', $title=null, $paytext=null, $ip, $sendMail=true, $freeParamsSession=null, $sessionId=null, $cvc2=null, $fraudDetection=1, $avsCheck=0, $update=0);

		/**
		 * Erstellt einen neuen Kunden und verknpft Kreditkartendaten.
		 *  Kombiniert die Funktionen 'customerCreate' und 'creditCardDataSet'
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $firstname (default=null)  Vorname des Kunden
		 * @param string $surname (default=null)  Nachname des Kunde
		 * @param string $number Kreditkartennummer
		 * @param integer $expiryYear Gltigkeits Jahr
		 * @param integer $expiryMonth Gltigkeits Monat
		 * @param integer $doublet (default=1)  Dublette erlauben, d.h. eine Kreditkartennummer kann von mehreren Customern verwendet werden. Wenn 0, dann scheitert die Funktion, siehe code 4105
		 * @param string $email (default=null)  E-Mail-Adresse des Kunden, wenn nach den Transaktionen einen E-Mail an der Kunden versand werden soll
		 * @param string $culture (default='de-DE')  Sprache & Land des Kunden | gltige Beispielwerte sind 'de', 'de-DE', 'en-US'
		 * @param string $customerId (default=null)  eigene eindeutige ID des Kunden, wird anderenfalls erzeugt [min./max. Zeichen 10/40, alphanumerisch]
		 * @param map $freeParams (default=null)  Liste mit freien Parametern, die dem Kunden zugeordnet werden
		 * @param integer $update (default=0)  bei bestehendem Customer: 0=error, 1=update aller Parameter, 2=update nur von gesetzten Parametern
		 * 
		 * @return struct 
		 * @result string $customerId eigene oder erzeugte eindeutige ID des Kunden
		 * @result boolean $cvc2Required gibt Auskunft darber, ob bei der nchsten Buchung der CVC2-Code erforderlich ist
		 */
		public function shortCustomerCreate($accessKey, $testMode=0, $firstname=null, $surname=null, $number, $expiryYear, $expiryMonth, $doublet=1, $email=null, $culture='de-DE', $customerId=null, $freeParams=null, $update=0);

		/**
		 * Erzeugt einen neuen Bezahlvorgang fr einen Kunden. Der Kunde und die Session werden angelegt.
		 *  Kombiniert die Funktionen 'customerCreate', 'creditCardDataSet' und 'sessionCreate'
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $firstname (default=null)  Vorname des Kunden
		 * @param string $surname (default=null)  Nachname des Kunde
		 * @param string $number Kreditkartennummer
		 * @param integer $expiryYear Gltigkeits Jahr
		 * @param integer $expiryMonth Gltigkeits Monat
		 * @param integer $doublet (default=1)  Dublette erlauben, d.h. eine Kreditkartennummer kann von mehreren Customern verwendet werden. Wenn 0, dann scheitert die Funktion, siehe code 4105
		 * @param string $email (default=null)  E-Mail-Adresse des Kunden, wenn nach den Transaktionen einen E-Mail an der Kunden versand werden soll
		 * @param string $culture (default='de-DE')  Sprache & Land des Kunden | gltige Beispielwerte sind 'de', 'de-DE', 'en-US'
		 * @param string $customerId (default=null)  eigene eindeutige ID des Kunden, wird anderenfalls erzeugt [min./max. Zeichen 10/40, alphanumerisch]
		 * @param map $freeParams (default=null)  Liste mit freien Parametern, die dem Kunden zugeordnet werden
		 * @param string $project das Projektkrzel fr den Vorgang
		 * @param string $projectCampaign (default=null)  ein Kampagnenkrzel des Projektbetreibers
		 * @param string $account (default=null)  Account des beteiligten Webmasters sonst eigener - setzt eine Aktivierung der Webmasterfhigkeit des Projekts vorraus - Hinweis: Webmasterfhigkeit steht momentan nicht zur Verfgung
		 * @param string $webmasterCampaign (default=null)  ein Kampagnenkrzel des Webmasters
		 * @param integer $amount (default=null)  abzurechnender Betrag, wird kein Betrag bergeben, wird der Betrag aus der Konfiguration verwendet
		 * @param string $currency (default='EUR')  Whrung
		 * @param string $title (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung in Falle einer auftretenden Benachrichtigung wird dieser Wert als Produktidentifizierung mit geschickt, wird kein Wert bergeben, wird Der aus der Konfiguration verwendet
		 * @param string $paytext (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung beim Mailversand, sollten Sie Diesen wnschen
		 * @param string $ip IPv4 des Benutzers
		 * @param boolean $sendMail (default=true) 
		 * @param map $freeParamsSession (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @param string $sessionId (default=null)  eigene eindeutige ID des Vorgangs, wird anderenfalls erzeugt [max. 40 Zeichen]
		 * @param integer $update (default=0)  bei bestehendem Customer: 0=error, 1=update aller Parameter, 2=update nur von gesetzten Parametern
		 * 
		 * @return struct 
		 * @result string $customerId eigene oder erzeugte eindeutige ID des Kunden
		 * @result boolean $cvc2Required gibt Auskunft darber, ob bei der nchsten Buchung der CVC2-Code erforderlich ist
		 * @result string $sessionId eigene oder erzeugte eindeutige ID des Vorgangs
		 * @result SessionStatus $status Vorgangsstatus "INIT"
		 * @result datetime $expire Ablaufzeit des Vorgangs
		 */
		public function shortSessionCreate($accessKey, $testMode=0, $firstname=null, $surname=null, $number, $expiryYear, $expiryMonth, $doublet=1, $email=null, $culture='de-DE', $customerId=null, $freeParams=null, $project, $projectCampaign=null, $account=null, $webmasterCampaign=null, $amount=null, $currency='EUR', $title=null, $paytext=null, $ip, $sendMail=true, $freeParamsSession=null, $sessionId=null, $update=0);

		/**
		 * sofortige Buchung
		 *  Kombiniert die Funktionen 'customerCreate', 'creditCardDataSet', 'sessionCreate' und 'transactionPurchase'
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $firstname (default=null)  Vorname des Kunden
		 * @param string $surname (default=null)  Nachname des Kunde
		 * @param string $number Kreditkartennummer
		 * @param integer $expiryYear Gltigkeits Jahr
		 * @param integer $expiryMonth Gltigkeits Monat
		 * @param integer $doublet (default=1)  Dublette erlauben, d.h. eine Kreditkartennummer kann von mehreren Customern verwendet werden. Wenn 0, dann scheitert die Funktion, siehe code 4105
		 * @param string $email (default=null)  E-Mail-Adresse des Kunden, wenn nach den Transaktionen einen E-Mail an der Kunden versand werden soll
		 * @param string $culture (default='de-DE')  Sprache & Land des Kunden | gltige Beispielwerte sind 'de', 'de-DE', 'en-US'
		 * @param string $customerId (default=null)  eigene eindeutige ID des Kunden, wird anderenfalls erzeugt [min./max. Zeichen 10/40, alphanumerisch]
		 * @param map $freeParams (default=null)  Liste mit freien Parametern, die dem Kunden zugeordnet werden
		 * @param string $project das Projektkrzel fr den Vorgang
		 * @param string $projectCampaign (default=null)  ein Kampagnenkrzel des Projektbetreibers
		 * @param string $account (default=null)  Account des beteiligten Webmasters sonst eigener - setzt eine Aktivierung der Webmasterfhigkeit des Projekts vorraus - Hinweis: Webmasterfhigkeit steht momentan nicht zur Verfgung
		 * @param string $webmasterCampaign (default=null)  ein Kampagnenkrzel des Webmasters
		 * @param integer $amount (default=null)  abzurechnender Betrag, wird kein Betrag bergeben, wird der Betrag aus der Konfiguration verwendet
		 * @param string $currency (default='EUR')  Whrung
		 * @param string $title (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung in Falle einer auftretenden Benachrichtigung wird dieser Wert als Produktidentifizierung mit geschickt, wird kein Wert bergeben, wird Der aus der Konfiguration verwendet
		 * @param string $paytext (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung beim Mailversand, sollten Sie Diesen wnschen
		 * @param string $ip IPv4 des Benutzers
		 * @param boolean $sendMail (default=true) 
		 * @param map $freeParamsSession (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @param string $sessionId (default=null)  eigene eindeutige ID des Vorgangs, wird anderenfalls erzeugt [max. 40 Zeichen]
		 * @param string $cvc2 (default=null)  CVC2-Code der Kreditkarte, mu min einmal pro Kreditkarte/Verfallszeit angegeben worden sein
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * @param integer $avsCheck (default=0)  de/aktiviert das AddressVerificationSystem
		 * @param integer $update (default=0)  bei bestehendem Customer: 0=error, 1=update aller Parameter, 2=update nur von gesetzten Parametern
		 * 
		 * @return struct 
		 * @result string $customerId eigene oder erzeugte eindeutige ID des Kunden
		 * @result string $sessionId eigene oder erzeugte eindeutige ID des Vorgangs
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 * @result AVSResult $avsResult (default=null)  wenn ein AVS-Check angefordert wurde dessen Ergebnis
		 */
		public function shortTransactionPurchase($accessKey, $testMode=0, $firstname=null, $surname=null, $number, $expiryYear, $expiryMonth, $doublet=1, $email=null, $culture='de-DE', $customerId=null, $freeParams=null, $project, $projectCampaign=null, $account=null, $webmasterCampaign=null, $amount=null, $currency='EUR', $title=null, $paytext=null, $ip, $sendMail=true, $freeParamsSession=null, $sessionId=null, $cvc2=null, $fraudDetection=1, $avsCheck=0, $update=0);

		/**
		 * sofortige Vorautorisierung
		 *  Kombiniert die Funktionen 'customerCreate', 'creditCardDataSet', 'sessionCreate' und 'transactionAuthorization'
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $firstname (default=null)  Vorname des Kunden
		 * @param string $surname (default=null)  Nachname des Kunde
		 * @param string $number Kreditkartennummer
		 * @param integer $expiryYear Gltigkeits Jahr
		 * @param integer $expiryMonth Gltigkeits Monat
		 * @param integer $doublet (default=1)  Dublette erlauben, d.h. eine Kreditkartennummer kann von mehreren Customern verwendet werden. Wenn 0, dann scheitert die Funktion, siehe code 4105
		 * @param string $email (default=null)  E-Mail-Adresse des Kunden, wenn nach den Transaktionen einen E-Mail an der Kunden versand werden soll
		 * @param string $culture (default='de-DE')  Sprache & Land des Kunden | gltige Beispielwerte sind 'de', 'de-DE', 'en-US'
		 * @param string $customerId (default=null)  eigene eindeutige ID des Kunden, wird anderenfalls erzeugt [min./max. Zeichen 10/40, alphanumerisch]
		 * @param map $freeParams (default=null)  Liste mit freien Parametern, die dem Kunden zugeordnet werden
		 * @param string $project das Projektkrzel fr den Vorgang
		 * @param string $projectCampaign (default=null)  ein Kampagnenkrzel des Projektbetreibers
		 * @param string $account (default=null)  Account des beteiligten Webmasters sonst eigener - setzt eine Aktivierung der Webmasterfhigkeit des Projekts vorraus - Hinweis: Webmasterfhigkeit steht momentan nicht zur Verfgung
		 * @param string $webmasterCampaign (default=null)  ein Kampagnenkrzel des Webmasters
		 * @param integer $amount (default=null)  abzurechnender Betrag, wird kein Betrag bergeben, wird der Betrag aus der Konfiguration verwendet
		 * @param string $currency (default='EUR')  Whrung
		 * @param string $title (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung in Falle einer auftretenden Benachrichtigung wird dieser Wert als Produktidentifizierung mit geschickt, wird kein Wert bergeben, wird Der aus der Konfiguration verwendet
		 * @param string $paytext (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung beim Mailversand, sollten Sie Diesen wnschen
		 * @param string $ip IPv4 des Benutzers
		 * @param boolean $sendMail (default=true) 
		 * @param map $freeParamsSession (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @param string $sessionId (default=null)  eigene eindeutige ID des Vorgangs, wird anderenfalls erzeugt [max. 40 Zeichen]
		 * @param string $cvc2 (default=null)  CVC2-Code der Kreditkarte, mu min einmal pro Kreditkarte/Verfallszeit angegeben worden sein
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * @param integer $avsCheck (default=0)  de/aktiviert das AddressVerificationSystem
		 * @param integer $update (default=0)  bei bestehendem Customer: 0=error, 1=update aller Parameter, 2=update nur von gesetzten Parametern
		 * 
		 * @return struct 
		 * @result string $customerId eigene oder erzeugte eindeutige ID des Kunden
		 * @result string $sessionId eigene oder erzeugte eindeutige ID des Vorgangs
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 * @result AVSResult $avsResult (default=null)  wenn ein AVS-Check angefordert wurde dessen Ergebnis
		 */
		public function shortTransactionAuthorization($accessKey, $testMode=0, $firstname=null, $surname=null, $number, $expiryYear, $expiryMonth, $doublet=1, $email=null, $culture='de-DE', $customerId=null, $freeParams=null, $project, $projectCampaign=null, $account=null, $webmasterCampaign=null, $amount=null, $currency='EUR', $title=null, $paytext=null, $ip, $sendMail=true, $freeParamsSession=null, $sessionId=null, $cvc2=null, $fraudDetection=1, $avsCheck=0, $update=0);

		/**
		 * sofortige Buchung. Bentigt einen bestehenden Customer, bevorzugt fr Folgebuchungen geeignet.
		 *  Kombiniert die Funktionen 'sessionCreate' und 'transactionPurchase'
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * @param string $sessionId (default=null)  eigene eindeutige ID des Vorgangs, wird anderenfalls erzeugt [max. 40 Zeichen]
		 * @param string $project das Projektkrzel fr den Vorgang
		 * @param string $cvc2 (default=null)  CVC2-Code der Kreditkarte, mu min einmal pro Kreditkarte/Verfallszeit angegeben worden sein
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * @param integer $avsCheck (default=0)  de/aktiviert das AddressVerificationSystem
		 * @param string $projectCampaign (default=null)  ein Kampagnenkrzel des Projektbetreibers
		 * @param string $account (default=null)  Account des beteiligten Webmasters sonst eigener - setzt eine Aktivierung der Webmasterfhigkeit des Projekts vorraus - Hinweis: Webmasterfhigkeit steht momentan nicht zur Verfgung
		 * @param string $webmasterCampaign (default=null)  ein Kampagnenkrzel des Webmasters
		 * @param integer $amount (default=null)  abzurechnender Betrag, wird kein Betrag bergeben, wird der Betrag aus der Konfiguration verwendet
		 * @param string $currency (default='EUR')  Whrung
		 * @param string $title (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung in Falle einer auftretenden Benachrichtigung wird dieser Wert als Produktidentifizierung mit geschickt, wird kein Wert bergeben, wird Der aus der Konfiguration verwendet
		 * @param string $paytext (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung beim Mailversand, sollten Sie Diesen wnschen
		 * @param string $ip IPv4 des Benutzers
		 * @param map $freeParamsSession (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @param boolean $sendMail (default=true) 
		 * 
		 * @return struct 
		 * @result string $sessionId eigene oder erzeugte eindeutige ID des Vorgangs
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 * @result AVSResult $avsResult (default=null)  wenn ein AVS-Check angefordert wurde dessen Ergebnis
		 */
		public function shortCustomerPurchase($accessKey, $testMode=0, $customerId, $sessionId=null, $project, $cvc2=null, $fraudDetection=1, $avsCheck=0, $projectCampaign=null, $account=null, $webmasterCampaign=null, $amount=null, $currency='EUR', $title=null, $paytext=null, $ip, $freeParamsSession=null, $sendMail=true);

		/**
		 * sofortige Vorautorisierung. Bentigt einen bestehenden Customer, bevorzugt fr Folgebuchungen geeignet.
		 *  Kombiniert die Funktionen 'sessionCreate' und 'transactionAuthorization'
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * @param string $sessionId (default=null)  eigene eindeutige ID des Vorgangs, wird anderenfalls erzeugt [max. 40 Zeichen]
		 * @param string $project das Projektkrzel fr den Vorgang
		 * @param string $cvc2 (default=null)  CVC2-Code der Kreditkarte, mu min einmal pro Kreditkarte/Verfallszeit angegeben worden sein
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * @param integer $avsCheck (default=0)  de/aktiviert das AddressVerificationSystem
		 * @param string $projectCampaign (default=null)  ein Kampagnenkrzel des Projektbetreibers
		 * @param string $account (default=null)  Account des beteiligten Webmasters sonst eigener - setzt eine Aktivierung der Webmasterfhigkeit des Projekts vorraus - Hinweis: Webmasterfhigkeit steht momentan nicht zur Verfgung
		 * @param string $webmasterCampaign (default=null)  ein Kampagnenkrzel des Webmasters
		 * @param integer $amount (default=null)  abzurechnender Betrag, wird kein Betrag bergeben, wird der Betrag aus der Konfiguration verwendet
		 * @param string $currency (default='EUR')  Whrung
		 * @param string $title (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung in Falle einer auftretenden Benachrichtigung wird dieser Wert als Produktidentifizierung mit geschickt, wird kein Wert bergeben, wird Der aus der Konfiguration verwendet
		 * @param string $paytext (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung beim Mailversand, sollten Sie Diesen wnschen
		 * @param string $ip IPv4 des Benutzers
		 * @param map $freeParamsSession (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @param boolean $sendMail (default=true) 
		 * 
		 * @return struct 
		 * @result string $sessionId eigene oder erzeugte eindeutige ID des Vorgangs
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 * @result AVSResult $avsResult (default=null)  wenn ein AVS-Check angefordert wurde dessen Ergebnis
		 */
		public function shortCustomerAuthorization($accessKey, $testMode=0, $customerId, $sessionId=null, $project, $cvc2=null, $fraudDetection=1, $avsCheck=0, $projectCampaign=null, $account=null, $webmasterCampaign=null, $amount=null, $currency='EUR', $title=null, $paytext=null, $ip, $freeParamsSession=null, $sendMail=true);

		/**
		 * Erstellt einen neuen Kunden, berschreibt ihn wenn gewnscht.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId (default=null)  eigene eindeutige ID des Kunden, wird anderenfalls erzeugt [min./max. Zeichen 10/40, alphanumerisch]
		 * @param map $freeParams (default=null)  Liste mit freien Parametern, die dem Kunden zugeordnet werden
		 * @param string $firstname (default=null)  Vorname des Kunden
		 * @param string $surname (default=null)  Nachname des Kunde
		 * @param string $email (default=null)  E-Mail-Adresse des Kunden, wenn nach den Transaktionen einen E-Mail an der Kunden versand werden soll
		 * @param string $culture (default='de-DE')  Sprache & Land des Kunden | gltige Beispielwerte sind 'de', 'de-DE', 'en-US'
		 * @param integer $update (default=0)  bei bestehendem Customer: 0=error, 1=update aller Parameter, 2=update nur von gesetzten Parametern
		 * 
		 * @return string eigene oder erzeugte eindeutige ID des Kunden
		 */
		public function customerCreate($accessKey, $testMode=0, $customerId=null, $freeParams=null, $firstname=null, $surname=null, $email=null, $culture='de-DE', $update=0);

		/**
		 * Verknpft Kreditkartendaten mit einem bestehenden Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * @param string $number Kreditkartennummer
		 * @param integer $expiryYear Gltigkeits Jahr
		 * @param integer $expiryMonth Gltigkeits Monat
		 * @param integer $doublet (default=1)  Dublette erlauben, d.h. eine Kreditkartennummer kann von mehreren Customern verwendet werden. Wenn 0, dann scheitert die Funktion, siehe code 4105
		 * 
		 * @return boolean Rckgabewert gibt Auskunft darber, ob bei der nchsten Buchung der CVC2-Code erforderlich ist - cvc2Required
		 */
		public function creditcardDataSet($accessKey, $testMode=0, $customerId, $number, $expiryYear, $expiryMonth, $doublet=1);

		/**
		 * Liefert Liste mit bestehenden Kunden.
		 *  Sortiert ist nach Erstellungszeitpunkt, ltester Wert zuerst. Erstellungszeitpunkt ist eindeutig.
		 *  Ein paging kann realisiert werden, indem der letzte Ergebnissatz als customerId Parameter beim Folgeaufruf verwendet wird.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0) 	aktiviert Testumgebung
		 * @param string $customerId (default=null) 	wenn angegeben werden nur Kunden gelistet, deren Erstellungszeitpunkt jnger oder identisch mit dem des angegebenen Kunden ist
		 * @param integer $onlyNewer (default=1) 	wenn 1 dann nur Kunden listen, deren Erstellungszeitpunkt jnger als bei dem angegebenen Kunden ist
		 * @param integer $onlyDoublet (default=0) 	wenn 1 dann nur Kunden listen, die sich mit anderen Kunden eine Kreditkartennummer teilen
		 * @param datetime $from (default=null) 	wenn angegeben nur Kunden listen deren Erstellungszeitpunkt >= dem angegeben Wert ist [YYYY-mm-dd HH:ii:ss]
		 * @param datetime $to (default=null) 	wenn angegeben nur Kunden listen deren Erstellungszeitpunkt < dem angegeben Wert ist [YYYY-mm-dd HH:ii:ss]
		 * @param integer $limit (default=20) 	maximale Anzahl der Liste, maximaler Wert ist 500
		 * 
		 * @return array 
		 * @result integer $count Anzahl Ergebnisstze in customer
		 * @result integer $more wenn 1 dann hat limit gegriffen, d.h. es gibt mehr Ergebnisstze fr das verwendete Filter
		 * @result string[] $customer (default=null)  Liste von customerId`s
		 */
		public function customerList($accessKey, $testMode=0, $customerId=null, $onlyNewer=1, $onlyDoublet=0, $from=null, $to=null, $limit=20);

		/**
		 * Liefert Liste mit Kunden die die gleiche Kreditkarte nutzen wie der zu prfende Kunde.
		 *  Sortiert ist nach Erstellungszeitpunkt, ltester Wert zuerst. Erstellungszeitpunkt ist eindeutig.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0) 	aktiviert Testumgebung
		 * @param string $customerId zu prfender Kunde
		 * @param datetime $from (default=null) 	wenn angegeben nur Kunden listen deren Erstellungszeitpunkt >= dem angegeben Wert ist [YYYY-mm-dd HH:ii:ss]
		 * @param datetime $to (default=null) 	wenn angegeben nur Kunden listen deren Erstellungszeitpunkt < dem angegeben Wert ist [YYYY-mm-dd HH:ii:ss]
		 * @param integer $limit (default=20) 	maximale Anzahl der Liste, maximaler Wert ist 500
		 * 
		 * @return array 
		 * @result integer $count Anzahl Ergebnisstze in customer
		 * @result integer $more wenn 1 dann hat limit gegriffen, d.h. es gibt mehr Ergebnisstze fr das verwendete Filter
		 * @result string[] $customer (default=null)   Liste von customerId`s
		 */
		public function customerDoubletList($accessKey, $testMode=0, $customerId, $from=null, $to=null, $limit=20);

		/**
		 * Gibt Informationen ber eine Transaktion anhand einer Transaktionsnummer zurck.
		 * 
		 *  Wenn sich `currencyInit` und `currencyBooked` unterscheiden, dann fehlt die native Untersttzung fr die gewnschte Whrung.
		 *  In diesem Fall erfolgte eine Umrechnung in eine nativ untersttzte Whrung.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $transactionId Transaktionsnummer
		 * 
		 * @return struct 
		 * @result string $transactionId Transaktionsnummer
		 * @result string $sessionId eindeutige ID des Vorgangs
		 * @result string $customerId ID des Kunden
		 * @result string $auth AuthCode
		 * @result integer $amountInit Betrag der abgerechnet werden sollte in currencyInit
		 * @result string $currencyInit Whrungseinheit mit der abgerechnet werden sollte
		 * @result integer $amountBooked gebuchter Betrag in currencyBooked
		 * @result string $currencyBooked Whrungseinheit mit der gebucht wurde
		 * @result integer $amountInternal abgerechneter Betrag in currencyInternal
		 * @result string $currencyInternal (default='EUR')  Whrungseinheit fr interne Verbuchung
		 * @result TransactionType $type Art der Transaktion
		 * @result TransactionStatus $status Status der Transaktion
		 * @result datetime $created Zeitpunkt der Transaktion
		 * @result string $ip IPv4 des Benutzers
		 * @result string $cardType (default=null)  Kartentyp, kann bei aktiviertem DataStorage-Feature null sein
		 * @result string $cardNumber (default=null)  partielle Kreditkartennummer [letzten 4 Stellen], kann bei aktiviertem DataStorage-Feature null sein
		 * @result integer $cardExpiryYear (default=null)  Gltigkeits Jahr, kann bei aktiviertem DataStorage-Feature null sein
		 * @result integer $cardExpiryMonth (default=null) 	Gltigkeits Monat, kann bei aktiviertem DataStorage-Feature null sein
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 * @result AVSResult $avsResult (default=null)  Wenn ein AVS-Check durchgefhrt wurde dessen Ergebnis
		 */
		public function transactionGet($accessKey, $testMode=0, $transactionId);

		/**
		 * Fhrt eine Transaktion zur sofortigen Buchung, des durch `sessionCreate` definierten Betrages, durch.
		 * 
		 *  Zur Durchfhrung der Transaktion ist es notwendig das Sie mittels `sessionCreate` einen Bezahlvorgang erstellt haben,
		 *  sowie dem Kunden, unter Zuhilfenahme von `creditcardDataSet`, Kreditkartendaten zugewiesen haben.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID des Vorgangs
		 * @param string $cvc2 (default=null)  CVC2-Code der Kreditkarte, mu min einmal pro Kreditkarte/Verfallszeit angegeben worden sein
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * @param integer $avsCheck (default=0)  de/aktiviert das AddressVerificationSystem
		 * 
		 * @return struct 
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 * @result AVSResult $avsResult (default=null)  wenn ein AVS-Check angefordert wurde dessen Ergebnis
		 */
		public function transactionPurchase($accessKey, $testMode=0, $sessionId, $cvc2=null, $fraudDetection=1, $avsCheck=0);

		/**
		 * Fhrt eine Transaktion zur Vorautorisierung, des durch `sessionCreate` definierten Betrages, durch.
		 * 
		 *  Der gewnschten Betrag wird fr Sie reserviert bis:
		 *  - Sie den Betrag mittels `transactionReversal` wieder freigeben
		 *  - Sie den Gesamt- oder Teilbetrag mit `transactionCapture` buchen
		 *  - die Reservierung nach ca. 14 Tagen automatisch wieder freigegeben wird
		 * 
		 *  Zur Durchfhrung der Transaktion ist es notwendig das Sie mittels `sessionCreate` einen Bezahlvorgang erstellt haben,
		 *  sowie dem Kunden, unter Zuhilfenahme von `creditcardDataSet`, Kreditkartendaten zugewiesen haben.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID des Vorgangs
		 * @param string $cvc2 (default=null)  CVC2-Code der Kreditkarte, mu min einmal pro Kreditkarte/Verfallszeit angegeben worden sein
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * @param integer $avsCheck (default=0)  de/aktiviert das AddressVerificationSystem
		 * 
		 * @return struct 
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 * @result AVSResult $avsResult (default=null)  wenn ein AVS-Check angefordert wurde dessen Ergebnis
		 */
		public function transactionAuthorization($accessKey, $testMode=0, $sessionId, $cvc2=null, $fraudDetection=1, $avsCheck=0);

		/**
		 * Versendet eine Benachrichtigung ber eine transaktionsbezogene Gutschrift
		 *  an die im ControlCenter angegebene URL und gibt Debuginformationen darber zurck
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=1)  aktiviert Testumgebung
		 * @param string $transactionId Transaktionsnummer einer PURCHASE- oder CAPTURE-Transaktion
		 * 
		 * @return string 
		 */
		public function transactionBackpayNotificationTest($accessKey, $testMode=1, $transactionId);

		/**
		 * Versendet eine Benachrichtigung ber einen Refund
		 *  an die im ControlCenter angegebene URL und gibt Debuginformationen darber zurck
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=1)  aktiviert Testumgebung
		 * @param string $transactionId Transaktionsnummer einer REFUND-Transaktion
		 * 
		 * @return string 
		 */
		public function transactionRefundNotificationTest($accessKey, $testMode=1, $transactionId);

		/**
		 * Versendet eine Benachrichtigung ber eine NICHT transaktionsbezogene Gutschrift
		 *  an die im ControlCenter angegebene URL und gibt Debuginformationen darber zurck
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=1)  aktiviert Testumgebung
		 * @param string $transactionId Transaktionsnummer einer CREDIT-Transaktion
		 * 
		 * @return string 
		 */
		public function transactionCreditNotificationTest($accessKey, $testMode=1, $transactionId);

		/**
		 * Gibt eine Liste von Bezahlvorgngen anhand von Parametern zurck
		 * 
		 *  Folgende frei kombinierbare Parameter stehen zur Verfgung:
		 *  - Kunde (customerId)
		 *  - Zeitraum von/bis (dtmFrom/dtmTo)
		 *  - SessionStatus (status)
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId (default=null)  eindeutige ID des Kunden oder [NULL] ohne Kundeneinschrnkung
		 * @param datetime $dtmFrom (default=null)  Anfang der Zeitraumbegrenzung oder [NULL] um diese Zeitraumbegrenzung nicht zu definieren
		 * @param datetime $dtmTo (default=null)  Ende der Zeitraumbegrenzung oder [NULL] um diese Zeitraumbegrenzung nicht zu definieren
		 * @param SessionStatus $status (default=null)  Nur Sessions mit dem gewnschten Status in das Ergebnisliste aufnehmen oder [NULL] um Statusfilter zu deaktivieren
		 * 
		 * @return string[] 
		 */
		public function sessionList($accessKey, $testMode=0, $customerId=null, $dtmFrom=null, $dtmTo=null, $status=null);

		/**
		 * Errechnet ein Scoring fr einen zuvor angelegten Kunden, den zugehrigen Kreditkartendaten sowie der IP-Adresse und ggf. Http-Request-Headern des Kunden.
		 *  Daher ist es fr die Verwendung sinnvoll mglichst alle Daten zu erfassen um die Genauigkeit des Scorings zu erhhen.
		 * 
		 *  Begrifflichkeiten:
		 *   E-Mail           E-Mail-Adressen aus Kundendaten
		 *   BillingCountry   Land des Kunden aus Adressendaten des Kunden [billCountry]
		 *   BillingLocation  Standort des Kunden aus Adressendaten des Kunden
		 *   BinCountry       Land der Kreditkartenbank (BIN-Code) [ccCountry]
		 *   IPCountry        Land durch IP ermittelt [ipCountry]
		 *   IPLocation       Standort ermittelt durch IP
		 * 
		 *  Wichtung  Wert
		 *     2.5    E-Mail (Anbieter von Temporren E-Mail-Adressen / Freemail Provider > hheres Risiko)
		 *     2.5    IPCountry != BillingCountry
		 *     2.0    BillingCountry != BinCountry
		 *     5.0    customerIp ist Anonymous-Proxy
		 *     2.5    customerIp ist bekannter Proxy
		 *    10.0    Entfernung IPLocation zu BillingLocation (hhere Entfernung = hheres Risiko)
		 *     5.0    E-Mail steht auf Badlist (Hochrisiko)
		 *     5.0    BillingLocation ist bekannter Maildrop (Postfach etc.)
		 *     5.0    IPCountry oder BillingCountry sind Hochrisikolnder - z.Z. sind das:
		 *              Egypt, Ghana, Indonesia, Lebanon, Macedonia, Morocco, Nigeria,
		 *              Pakistan, Romania, Serbia and Montenegro, Ukraine, Vietnam
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId eindeutige ID des Kunden
		 * @param string $customerIp IPv4 des Benutzers
		 * @param map $customerRequestHeader (default=null)  Liste mit Http-Request-Headern des Kunden - ausgewertet werden: User-Agent, Accept-Language sowie die Proxy-Header X-Forwarded-For/Client-Ip
		 * 
		 * @return struct 
		 * @result string $billCountry (default=null)  Land [ISO 3166-1-alpha-2] aus den Adressdaten des Kundensatzes bspw. DE, AT, CH
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result float $scoreValue (default=null)  Bewertung mit Werten zwischen 0 und 100, wobei 0 fr geringes und 100 fr hohes Risiko steht
		 * @result string $scoreExplanation (default=null)  Erluterung zu der Bewertung in Textform [Englisch]
		 */
		public function customerScoring($accessKey, $testMode=0, $customerId, $customerIp, $customerRequestHeader=null);

		/**
		 * Fhrt eine Transaktion zur Buchung (Gesamt- oder Teilbetrag) einer Vorautorisierung durch.
		 * 
		 *  Sie buchen den reservierten Betrag:
		 *  - In voller Hhe (Gesamtbetrag) - der Parameter `amount` entfllt ([NULL])
		 *  - Oder nur einen Teilbetrag - der Parameter `amount` enthlt den gewnschten Teilbetrag
		 * 
		 *  Zur Durchfhrung der Transaktion ist es notwendig das Sie mittels `sessionCreate` einen Bezahlvorgang,
		 *  sowie unter Verwendung von `transactionAuthorization` eine Vorautorisierung, erstellt haben.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID des Vorgangs
		 * @param string $transactionId (default=null)  Transaktionsnummer von "transactionAuthorization"
		 * @param integer $amount (default=null)  [NULL] - entspricht Betrag aus Vorautorisierung | wenn abweichend, der zu buchende Betrag <= Betrag aus Vorautorisierung
		 * @param string $currency (default=null)  Whrung, falls abweichend von Originaltransaktion [nur relevant wenn `amount` abweichend]
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * 
		 * @return struct 
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 */
		public function transactionCapture($accessKey, $testMode=0, $sessionId, $transactionId=null, $amount=null, $currency=null, $fraudDetection=1);

		/**
		 * Transaktion zur Buchung einer Gesamt- oder Teilrckzahlung einer den Kunden belastende Buchung.
		 * 
		 *  Sie erstatten den gebuchten Betrag:
		 *  - In voller Hhe (Gesamtbetrag) - der Parameter `amount` entfllt ([NULL])
		 *  - Oder nur einen Teilbetrag - der Parameter `amount` enthlt den gewnschten Teilbetrag
		 * 
		 *  Zur Durchfhrung der Transaktion ist es notwendig das Sie mittels `sessionCreate` einen Bezahlvorgang erstellt,
		 *  sowie unter Verwendung von `transactionPurchase` oder `transactionCapture` eine den Kunden belastende Buchung durchgefhrt haben.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID des Vorgangs
		 * @param string $transactionId Transaktionsnummer der Transaktion die zurckgebucht werden soll
		 * @param integer $amount (default=null)  zurckzubuchender Betrag, falls abweichend von Orginaltransaktion
		 * @param string $currency (default=null)  Whrung, falls abweichend von Originaltransaktion [nur relevant wenn `amount` abweichend]
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * 
		 * @return struct 
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 */
		public function transactionRefund($accessKey, $testMode=0, $sessionId, $transactionId, $amount=null, $currency=null, $fraudDetection=1);

		/**
		 * Transaktion zur Buchung einer nicht transaktionsbezogenen Gutschrift.
		 * 
		 *  Dies ermglicht es Ihnen beliebige Betrge auf das Kreditkartenkonto einen Kunden zu bertragen.
		 * 
		 *  Zur Durchfhrung der Transaktion ist es notwendig das Sie mittels `sessionCreate` einen Bezahlvorgang erstellt haben,
		 *  sowie dem Kunden, unter Zuhilfenahme von `creditcardDataSet`, Kreditkartendaten zugewiesen haben.
		 * 
		 *  HINWEIS:
		 *  Diese Funktionalitt bedarf manueller Freischaltung, und wird vom buchbaren Volumen beschrnkt
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID des Vorgangs
		 * @param integer $amount (default=null)  zurckzubuchender Betrag, falls abweichend von Orginaltransaktion
		 * @param string $currency (default=null)  Whrung, falls abweichend von Originaltransaktion [nur relevant wenn `amount` abweichend]
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * 
		 * @return struct 
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $ccCountry (default=null)  Land [ISO 3166-1-alpha-2] der Kreditkarte wenn verfgbar, bspw. DE, AT, CH
		 * @result string $ipCountry (default=null)  Land [ISO 3166-1-alpha-2] der IP wenn verfgbar, bspw. GB, US
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 */
		public function transactionCredit($accessKey, $testMode=0, $sessionId, $amount=null, $currency=null, $fraudDetection=1);

		/**
		 * Zuordnung einer `dataStorageId` von einem Bestandskunden Ihres Systems zu einem Kunden (customerId) bei micropayment
		 * 
		 *  Wichtig:
		 *  Diese Funktion ist nur bei einem Wechsel von einem anderen DataStorage-Anbieter relevant und setzt den
		 *  Import der zugehrigen Kreditkartendaten vorraus separat beantragt und durchgefhrt werden muss.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * @param string $dataStorageId Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * 
		 * @return boolean 
		 */
		public function dataStorageIdImport($accessKey, $testMode=0, $customerId, $dataStorageId);

		/**
		 * Gibt die mit einem Kunden verknpften Kreditkartendaten zurck.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * 
		 * @return struct 
		 * @result string $type (default=null)  Kartentyp
		 * @result string $number (default=null)  partielle Kreditkartennummer [letzten 4 Stellen]
		 * @result integer $expiryYear (default=null)  Gltigkeits Jahr
		 * @result integer $expiryMonth (default=null) 	Gltigkeits Monat
		 * @result boolean $cvc2Required Bei der nchsten Buchung ist der CVC2-Code erforderlich
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 */
		public function creditcardDataGet($accessKey, $testMode=0, $customerId);

		/**
		 * Transaktion zur gebhrenfreier Stornierung einer Buchung vor Kassenschnitt oder Freigabe von Vorautorisierungen.
		 * 
		 *  Die gebhrenfreie Stornierung einer mit `transactionPurchase` durchgefhrten Buchung muss am gleichen Tag vor Kassenschnitt um 24 Uhr erfolgen.
		 *  Die Freigabe einer mittels `transactionAuthorization` erstellten Vorautorisierungen hingegen kann jederzeit durchgefhrt werden.
		 * 
		 *  Zur Durchfhrung der Transaktion ist es notwendig das Sie mittels `sessionCreate` einen Bezahlvorgang erstellt,
		 *  sowie unter Verwendung von `transactionAuthorization` eine Vorautorisierung oder mit `transactionPurchase` eine Buchung durchgefhrt haben.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID des Vorgangs
		 * @param string $transactionId Transaktionsnummer der Transaktion die zurckgebucht werden soll
		 * @param integer $fraudDetection (default=1)  de/aktiviert FraudDetection
		 * 
		 * @return struct 
		 * @result SessionStatus $sessionStatus Status der gesamten Session
		 * @result TransactionStatus $transactionStatus Status der ausgelsten Transaktion
		 * @result string $transactionId Transaktionsnummer
		 * @result datetime $transactionCreated Zeitpunkt der Transaktion
		 * @result string $transactionAuth AuthCode
		 * @result string $dataStorageId (default=null)  Wenn DataStorage-Feature aktiv, ID der Kreditkartendaten im DataStorage-Service
		 * @result string $transactionResultCode Transaktionergebnis-Code vom Terminal
		 * @result string $transactionResultMessage Transaktionergebnis-Nachricht vom Terminal
		 */
		public function transactionReversal($accessKey, $testMode=0, $sessionId, $transactionId, $fraudDetection=1);

		/**
		 * Gibt eine Liste der, vom System durch Umrechnung, untersttzten Whrungen zurck.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * 
		 * @return string[] 
		 */
		public function currenciesGetSupported($accessKey, $testMode=0);

		/**
		 * Gibt eine Liste der, von Ihrem Account, nativ untersttzten Whrungen, optional fr einen bestimmten Kartentyp, zurck.
		 * 
		 *  Hinweis:
		 *  Die native Untersttzung weiterer Whrungen erhalten Sie durch die Beantragung zustzlicher VU-Nummern.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param CardType $cardtype (default=null)  Typ der Kreditkarte
		 * 
		 * @return string[] 
		 */
		public function currenciesGetNativeSupported($accessKey, $testMode=0, $cardtype=null);

		/**
		 * berprfung von Kreditkarten-Daten (Nummer und Ablaufdatum) auf Gltigkeit
		 * 
		 *  - syntaktischen berprfung
		 *  - Luhn-Check
		 *  - berschreitung des Ablaufdatums
		 * 
		 *  Hinweis: Es findet keine Online-berprfung der Daten statt!
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $number Kreditkartennummer
		 * @param integer $expiryYear Gltigkeits Jahr
		 * @param integer $expiryMonth Gltigkeits Monat
		 * 
		 * @return boolean Kreditkarten-Daten sind syntaktisch gltig
		 */
		public function creditcardCheckValidity($accessKey, $testMode=0, $number, $expiryYear, $expiryMonth);

		/**
		 * Lscht alle im Testmodus bertragenen Daten
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=1)  aktiviert Testumgebung
		 * 
		 * @return boolean 
		 */
		public function resetTest($accessKey, $testMode=1);

		/**
		 * Versendet eine Benachrichtigung ber ein Chargeback an die im
		 *  ControlCenter angegebene URL und gibt Debuginformationen darber zurck
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=1)  aktiviert Testumgebung
		 * @param string $transactionId Transaktionsnummer einer PURCHASE- oder CAPTURE-Transaktion
		 * 
		 * @return string 
		 */
		public function transactionChargebackNotificationTest($accessKey, $testMode=1, $transactionId);

		/**
		 * Verknpft Adressdaten mit einem bestehenden Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)   aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * @param string $address Strasse und Hausnummer
		 * @param string $zipcode Postleitzahl
		 * @param string $town Ort
		 * @param string $country Land [ISO 3166-1-alpha-2] bspw. DE, AT, CH
		 * 
		 * @return boolean 
		 */
		public function addressSet($accessKey, $testMode=0, $customerId, $address, $zipcode, $town, $country);

		/**
		 * Gibt die mit einem Kunden verknpften Adressdaten zurck.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)   aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * 
		 * @return array 
		 * @result string $address Strasse und Hausnummer
		 * @result string $zipcode Postleitzahl
		 * @result string $town Ort
		 * @result string $country Land [ISO 3166-1-alpha-2] bspw. DE, AT, CH
		 */
		public function addressGet($accessKey, $testMode=0, $customerId);

		/**
		 * ndert Daten eines bestehenden Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId eindeutige ID des Kunden
		 * @param map $freeParams (default=null)  Liste mit freien Parametern: [NULL] - Parameterliste bleibt unverndert | leeres HashMap - lscht Parameterliste | geflltes HashMap erweitert/berschreibt bestehende Parameterliste
		 * @param string $firstname (default=null)  Vorname des Kunden: [NULL] - aktueller Wert bleibt erhalten | gltiger Wert z.B 'Max'
		 * @param string $surname (default=null)  Nachname des Kunde: [NULL] - aktueller Wert bleibt erhalten | gltiger Wert z.B 'Mustermann'
		 * @param string $email (default=null)  E-Mail-Adresse des Kunden: [NULL] - aktueller Wert bleibt erhalten | gltiger Wert z.B. 'max@mustermann.de' ersetzt den aktuellen Wert
		 * @param string $culture (default=null)  Sprache & Land des Kunden: [NULL] - aktueller Wert bleibt erhalten | gltige Wert z.B. 'de-DE' ersetzt den aktuellen Wert
		 * 
		 * @return boolean 
		 */
		public function customerSet($accessKey, $testMode=0, $customerId, $freeParams=null, $firstname=null, $surname=null, $email=null, $culture=null);

		/**
		 * Gibt die Daten eines bestehenden Kunden zurck.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * 
		 * @return struct 
		 * @result map $freeParams (default=null)  Liste mit allen freien Parametern
		 * @result string $firstname (default=null)  Vorname des Kunden
		 * @result string $surname (default=null)  Nachname des Kunden
		 * @result string $email (default=null)  E-Mail-Adresse des Kunden
		 * @result string $culture (default=null)  Sprache & Land des Kunden
		 */
		public function customerGet($accessKey, $testMode=0, $customerId);

		/**
		 * Erzeugt einen neuen Bezahlvorgang fr einen Kunden
		 * 
		 *  Zur Durchfhrung wird zwingender Weise ein Kunde (customerId) bentigt, den Sie mittels `customerCreate` anlegen knnen.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * @param string $sessionId (default=null)  eigene eindeutige ID des Vorgangs, wird anderenfalls erzeugt [max. 40 Zeichen]
		 * @param string $project das Projektkrzel fr den Vorgang
		 * @param string $projectCampaign (default=null)  ein Kampagnenkrzel des Projektbetreibers
		 * @param string $account (default=null)  Account des beteiligten Webmasters sonst eigener - setzt eine Aktivierung der Webmasterfhigkeit des Projekts vorraus - Hinweis: Webmasterfhigkeit steht momentan nicht zur Verfgung
		 * @param string $webmasterCampaign (default=null)  ein Kampagnenkrzel des Webmasters
		 * @param integer $amount (default=null)  abzurechnender Betrag, wird kein Betrag bergeben, wird der Betrag aus der Konfiguration verwendet
		 * @param string $currency (default='EUR')  Whrung
		 * @param string $title (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung in Falle einer auftretenden Benachrichtigung wird dieser Wert als Produktidentifizierung mit geschickt, wird kein Wert bergeben, wird Der aus der Konfiguration verwendet
		 * @param string $paytext (default=null)  Bezeichnung der zu kaufenden Sache - Verwendung beim Mailversand, sollten Sie Diesen wnschen
		 * @param string $ip IPv4 des Benutzers
		 * @param map $freeParams (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @param boolean $sendMail (default=true) 
		 * 
		 * @return struct 
		 * @result string $sessionId eigene oder erzeugte eindeutige ID des Vorgangs
		 * @result SessionStatus $status Vorgangsstatus "INIT"
		 * @result datetime $expire Ablaufzeit des Vorgangs
		 */
		public function sessionCreate($accessKey, $testMode=0, $customerId, $sessionId=null, $project, $projectCampaign=null, $account=null, $webmasterCampaign=null, $amount=null, $currency='EUR', $title=null, $paytext=null, $ip, $freeParams=null, $sendMail=true);

		/**
		 * Gibt Informationen ber einen Bezahlvorgang, inklusive einer Liste von verknpften Transaktionen, zurck.
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId eindeutige ID des Vorgangs
		 * 
		 * @return struct 
		 * @result string $customerId ID des Kunden
		 * @result string $project das Projektkrzel fr den Vorgang
		 * @result string $projectCampaign ein Kampagnenkrzel des Projektbetreibers
		 * @result string $account Account des beteiligten Webmasters sonst eigener
		 * @result string $webmasterCampaign ein Kampagnenkrzel des Webmasters
		 * @result integer $amount abzurechnender Betrag, wird kein Betrag bergeben, wird der Betrag aus der Konfiguration verwendet
		 * @result string $currency Whrungseinheit
		 * @result string $title Bezeichnung der zu kaufenden Sache
		 * @result string $ip IPv4 des Benutzers
		 * @result map $freeParams (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @result SessionStatus $status 
		 * @result datetime $expire (default=null)  Verfallsdatum der Session, nur wenn $status INIT oder EXPIRED
		 * @result MailStatus $mail Status des Mailversands
		 * @result string[] $transactionIds (default=null)  Liste von TransaktionsIds die mit dieser Session verknpft sind
		 */
		public function sessionGet($accessKey, $testMode=0, $sessionId);

	}

?>