<?php

	/**
	 * Api steuert die Bezahlung per Lastschrift.
	 * 
	 *  Neuerungen SEPA:
	 * 
	 *  Mit SEPA ( Single Euro Payments Area ), dem einheitlichen Euro-Zahlungsverkehrsraum, werden auch in Deutschland zum 01.02.2014 neue,
	 *  europaweit einheitliche Verfahren fr den bargeldlosen Zahlungsverkehr (berweisungen, Lastschriften) eingefhrt.
	 * 
	 *  Das bisheriege Verfahren mit Bankleitzahl und Kontonummer wird durch IBAN und BIC abgelt.
	 * 
	 *  IBAN (International Bank Account Number) ist die internationale Kontonummer und ersetzt Bankleitzahl und Kontonummer.
	 *  Fr grenzberschreitende Zahlungen ist noch der BIC (Business Identifier Code) als international standardisierter
	 *  Bank-Code (vergleichbar mit der Bankleitzahl in Deutschland) erforderlich.
	 * 
	 *  Fr Zahlungen / Lastschriften innerhalb Deutschlands reicht die Verwendung der IBAN (iban only) aus, fr alle anderen Transaktionen wird IBAN und BIC bentigt.
	 * 
	 *  Fr eine ordentliche SEPA-Zahlung sind noch folgende Punkte wichtig:
	 *  Mandate (mandateRef), Glubiger-ID (creditorId) und Prenotification (Nachricht ber die Kundenbelastung; payDate).
	 * 
	 * 
	 *  Mandate:
	 *  Parametername "mandateRef", "mandateSignDate"
	 *  Ein Mandat ist die Ermchtigung des Zahlungsempfngers durch den Zahlungspflichtigen mit einer Lastschrift vereinbarte Betrge abzubuchen.
	 *  Die Mandatsreferenz wird durch den Zahlungsempfnger frei vergeben und mu eindeutig sein.
	 *  In der Regel wird sie durch die Debit-API erstellt, siehe Rckgabe bei "sessionCreate". 
	 *   
	 *  Wird eine eigene Mandatsreferenz bergeben, und existiert dieses Mandat noch nicht, kann das Datum der Mandatserteilung bergeben werden. Anderenfalls wird es ermittelt bzw.
	 *  das Datum des sessionApprove Aufrufs angenommen.   
	 * 
	 *  
	 *  Mehrfach-Mandate:
	 *  Parametername "mandateRecur", "payRecurState"
	 *  Durch "mandateRecur" wird mitgeteilt, ob eine einmalige Lastschrift "ONEOFF" oder eine von mehreren Lastschriften "RECURRING" angelegt wird. 
	 *  Mit "FINAL" wird ein ggf. bestehendes Mandat geschlossen, d.h. das aktuelle Mandat wird letzmalig benutzt.
	 *    
	 *  Wird ein neues einmaliges Sepamandat mit "ONEOFF" erstellt, enthlt "payRecurState" immer den Status 'OOFF'. Die Mandatsreferenz darf danach nicht mehr benutzt werden.
	 *  Eine Mehrfachsession liefert "FRST" wenn das Mandat neu ist oder "RCUR" wenn es bereits benutzt wurde. Wurde mit "FINAL" das Mandat geschlossen, enthlt
	 *  "payRecurState" den Wert "FNAL". Auch hier darf die Mandatsreferenz nicht mehr benutzt werden.
	 * 
	 *  Glubiger-ID:
	 *  Parametername "creditorId"
	 *  Die Glubiger-Identifikationsnummer ist eine eindeutige Identifizierung fr Zahlungsempfnger von SEPA-Mandaten.
	 *  Sie ist fr jeden Zahlungsempfnger verpflichtend und kann bei der Bundesbank kostenlos beantragt werden, siehe https://extranet.bundesbank.de/scp/ .
	 *  Die Glubiger-ID ist im ControlCenter unter Kundendaten->Glubiger-Identifikationsnummer hinterlegt.
	 *  Alternativ wird die Glubiger-ID von micropayment bereitgestellt.
	 * 
	 *  Prenotification:
	 *  Der Endkunde mu vor der Belastung (siehe auch "payDate") in geeigneter Weise informiert werden. Ein geeigneter Textvorschlag kann wie folgt aussehen
	 *  (wobei die Platzhalter in {} durch die tatschlichen Werte ersetzt werden mssen)
	 * 
	 *  "Unsere Forderung in Hhe von {$amount} ziehen wir mit der SEPA-Lastschrift zum Mandat Nr. {$mandateRef} zu der Glubiger-Identifikationsnummer {$creditorId}
	 *   von Ihrem Konto IBAN {$iban} bei der {$bank} BIC {$bic} zum Flligkeitstag {$payDate} ein. Wir bitten Sie fr Kontodeckung zu sorgen."
	 *  
	 *  Vor jeder Folgelastschrift bei Mehrfach-Mandaten muss ebenfass der Kunde benachrichtigt werden.
	 * 
	 *  ------------------------------------------------------------------------------------
	 * 
	 *  Alle Funktionen die bisher mit Bankleitzahl/Kontonummer aufgerufen wurden, knnen jetzt alternativ mit IBAN/BIC bedient werden.
	 *  Bei Aufrufen ohne IBAN ist der Parametername "country" wichtig.
	 * 
	 *  Fehlercodes:
	 * 
	 *   4101	// Bankleitzahl ist ungltig
	 *   4102	// Kontonummer ist ungltig
	 *   4103	// Es wurde keine Kontoverbindung hinterlegt
	 *   4104	// Vorgang wurde bereits besttigt
	 *   4105	// Kontoverbindung wurde gesperrt
	 *   4106	// Limit erreicht
	 *   4107	// kein offener Betrag oder bersteigt Sessionbetrag
	 *   4108	// iban ist ungltig
	 *   4109	// Land ist ungltig
	 * 
	 *  ------------------------------------------------------------------------------------
	 *  
	 *  Hinweise zum TestModus: 
	 *  - Aktivierung der Testumgebung erfolgt in der jeweiligen Funktion ber den Parameter `testMode=1`
	 *  - um automatisierte interne Prozesse und Ereignisse zu simulieren, stehen die ...Test-Funktionen zur Verfgung. Um eine vollumfngliche Lastschrift mit allen Eventualitten zu simulieren sind folgende Funktionsaufrufe sinnvoll:
	 *  	customerCreate (Kunden anlegen)
	 *  	bankaccountSet (Bankverbindung anlegen)
	 *  	sessionCreate (Bezahlvorgang erzeugen)
	 *  	sessionApprove (Lastschrift besttigen)
	 *  	sessionChargeTest (Abbuchung simulieren) 
	 *  	sessionReverseTest (Rcklastschrift simulieren) 
	 *  	sessionRechargeTest (Nachzahlung simulieren) 
	 *  	transactionCreate (Nachzahlung auf eig. Konto verbuchen) 
	 *  	sessionRefund (Rckberweisung) 
	 *  	sessionRefundReverseTest (Retour der Rckberweisung simulieren) 
	 *  - fr den TestModus steht neben allen regulren, folgende Test-Bankverbindung zur Verfgung, um erfolgreiche Buchungen zu simulieren: 
	 *  	bankCode: 88888888
	 *  	accountNumber: z.B: 1234567890
	 *  	iban: z.B: DE89888888881234567890
	 *  	bic: TESTDE00XXX (optional)
	 *
	 * @copyright 2016 micropayment GmbH
	 * @link http://www.micropayment.de/
	 * @author Holger Heyne
	 * @version 2.1
	 * @created 2016-02-12 14:23:36
	 */
	interface IMcpDebitService_v2_1 {

		/**
		 * lscht alle Kunden und Transaktionen in der Testumgebung
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode Muss 1 sein
		 * 
		 * @return void 
		 */
		public function resetTest($accessKey, $testMode);

		/**
		 * legt neuen Kunden an
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId (default=null)  eigene eindeutige ID des Kunden, wird anderenfalls erzeugt
		 * @param array $freeParams (default=null)  Liste mit freien Parametern, die dem Kunden zugeordnet werden
		 * 
		 * @return array 
		 * @result string $customerId eigene oder erzeugte eindeutige ID des Kunden
		 */
		public function customerCreate($accessKey, $testMode=0, $customerId=null, $freeParams=null);

		/**
		 * ordnet weitere freie Parameter dem Kunden zu, oder ndert sie
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId eindeutige ID des Kunden
		 * @param array $freeParams (default=null)  Liste mit zustzlichen freien Parametern
		 * 
		 * @return void 
		 */
		public function customerSet($accessKey, $testMode=0, $customerId, $freeParams=null);

		/**
		 * ermittelt alle freien Parameter des Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * 
		 * @return array 
		 * @result array $freeParams (default=null)  Liste mit allen freien Parametern
		 */
		public function customerGet($accessKey, $testMode=0, $customerId);

		/**
		 * ermittelt alle Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param integer $from (default=0)  Position des ersten auszugebenden Kunden
		 * @param integer $count (default=100)  Anzahl der auszugebenden Kunden
		 * 
		 * @return array 
		 * @result array $customerIdList Liste mit allen freien Parametern
		 * @result integer $count Anzahl der Kunden in der Liste
		 * @result integer $maxCount Gesamtanzahl aller Kunden
		 */
		public function customerList($accessKey, $testMode=0, $from=0, $count=100);

		/**
		 * erzeugt oder ndert Bankverbindung eines Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * @param string $iban (default=null)  IBAN
		 * @param string $bic (default=null)  BIC, opt. bei deutscher IBAN
		 * @param string $country (default='DE')  Sitz der Bank, wenn IBAN leer ist
		 * @param string $bankCode (default=null)  Bankleitzahl, wenn IBAN leer ist
		 * @param string $accountNumber (default=null)  Kontonummer, wenn IBAN leer ist
		 * @param string $accountHolder Kontoinhaber
		 * 
		 * @return array 
		 * @result string $iban IBAN
		 * @result string $bic BIC
		 * @result string $country Sitz der Bank
		 * @result string $bankName Name der Bank
		 * @result string $bankCode Bankleitzahl
		 * @result string $accountNumber Kontonummer
		 * @result string $accountHolder Kontoinhaber
		 * @result string $barStatus Sperr-Status der Kontoverbindung
		 */
		public function bankaccountSet($accessKey, $testMode=0, $customerId, $iban=null, $bic=null, $country='DE', $bankCode=null, $accountNumber=null, $accountHolder);

		/**
		 * ermittelt die Bankverbindung des Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * 
		 * @return array 
		 * @result string $iban IBAN
		 * @result string $bic BIC
		 * @result string $country Sitz der Bank
		 * @result string $bankName Name der Bank
		 * @result string $bankCode Bankleitzahl
		 * @result string $accountNumber Kontonummer
		 * @result string $accountHolder Kontoinhaber
		 * @result string $barStatus Sperr-Status der Kontoverbindung
		 */
		public function bankaccountGet($accessKey, $testMode=0, $customerId);

		/**
		 * prft Bankleitzahl und ermittelt Banknamen
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $iban (default=null)  IBAN
		 * @param string $bic (default=null)  BIC, alternativ zur IBAN
		 * @param string $country (default='DE')  Sitz der Bank, alternativ zu IBAN und BIC
		 * @param string $bankCode (default=null)  Bankleitzahl, alternativ zu IBAN und BIC
		 * 
		 * @return array 
		 * @result string $bic BIC
		 * @result string $country Sitz der Bank
		 * @result string $bankName Name der Bank
		 * @result string $bankCode Bankleitzahl
		 * @result string $orderStatus Autragsart der Bank ALL = Lastschriften, berweisungen, CREDIT = nur berweisung, DENIED = Gesperrt fr Zahlungverkehr,
		 */
		public function bankCheck($accessKey, $testMode=0, $iban=null, $bic=null, $country='DE', $bankCode=null);

		/**
		 * prft Bankverbindung und ermittelt Banknamen
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $iban (default=null)  IBAN
		 * @param string $bic (default=null)  BIC, opt. bei deutscher IBAN
		 * @param string $country (default='DE')  Sitz der Bank, wenn IBAN leer ist
		 * @param string $bankCode (default=null)  Bankleitzahl, wenn IBAN leer ist
		 * @param string $accountNumber (default=null)  Kontonummer, wenn IBAN leer ist
		 * 
		 * @return array 
		 * @result string $iban IBAN
		 * @result string $bic BIC
		 * @result string $country Sitz der Bank
		 * @result string $bankName Name der Bank
		 * @result string $bankCode Bankleitzahl
		 * @result string $orderStatus Autragsart der Bank ALL = Lastschriften, berweisungen, CREDIT = nur berweisung, DENIED = Gesperrt fr Zahlungverkehr,
		 * @result string $accountNumber Kontonummer
		 * @result string $barStatus Sperr-Status der Kontoverbindung
		 */
		public function bankaccountCheck($accessKey, $testMode=0, $iban=null, $bic=null, $country='DE', $bankCode=null, $accountNumber=null);

		/**
		 * Sperrt Bankverbindung oder gibt sie frei
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $iban (default=null)  IBAN
		 * @param string $bic (default=null)  BIC, opt. bei deutscher IBAN
		 * @param string $country (default='DE')  Sitz der Bank, wenn IBAN leer ist
		 * @param string $bankCode (default=null)  Bankleitzahl, wenn IBAN leer ist
		 * @param string $accountNumber (default=null)  Kontonummer, wenn IBAN leer ist
		 * @param string $barStatus Sperr-Status BARRED, ALLOWED
		 * 
		 * @return void 
		 */
		public function bankaccountBar($accessKey, $testMode=0, $iban=null, $bic=null, $country='DE', $bankCode=null, $accountNumber=null, $barStatus);

		/**
		 * erzeugt oder ndert Adressdaten eines Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * @param string $firstName (default=null)  Vorname
		 * @param string $surName (default=null)  Nachname
		 * @param string $company (default=null)  Firma
		 * @param string $street (default=null)  Strasse und Hausnummer
		 * @param string $zip (default=null)  Postleitzahl
		 * @param string $city (default=null)  Ort
		 * @param string $country (default='DE')  Land
		 * 
		 * @return void 
		 */
		public function addressSet($accessKey, $testMode=0, $customerId, $firstName=null, $surName=null, $company=null, $street=null, $zip=null, $city=null, $country='DE');

		/**
		 * ermittelt die Adresse des Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * 
		 * @return array 
		 * @result string $firstName Vorname
		 * @result string $surName Nachname
		 * @result string $company Firma
		 * @result string $street Strasse und Hausnummer
		 * @result string $zip Postleitzahl
		 * @result string $city Ort
		 * @result string $country Land
		 */
		public function addressGet($accessKey, $testMode=0, $customerId);

		/**
		 * erzeugt oder ndert Kontaktdaten eines Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * @param string $email (default=null)  Emailadresse des Kunden
		 * @param string $phone (default=null)  Festnetzanschluss
		 * @param string $mobile (default=null)  Handynummer
		 * 
		 * @return void 
		 */
		public function contactDataSet($accessKey, $testMode=0, $customerId, $email=null, $phone=null, $mobile=null);

		/**
		 * ermittelt die Kontaktdaten des Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * 
		 * @return array 
		 * @result string $email Emailadresse
		 * @result string $phone Festnetzanschluss
		 * @result string $mobile Handynummer
		 */
		public function contactDataGet($accessKey, $testMode=0, $customerId);

		/**
		 * erzeugt einen neuen Bezahlvorgang
		 *  lst die Benachrichtigung sessionStatus mit dem Status "INIT" bzw. "REINIT" aus
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId ID des Kunden
		 * @param string $sessionId (default='')  eigene eindeutige ID des Vorgangs, wird anderenfalls erzeugt
		 * @param string $project das Projektkrzel fr den Vorgang
		 * @param string $projectCampaign (default='')  ein Kampagnenkrzel des Projektbetreibers
		 * @param string $account (default='')  Account des beteiligten Webmasters
		 * @param string $webmasterCampaign (default='')  ein Kampagnenkrzel des Webmasters
		 * @param integer $amount (default=0)  abzurechnender Betrag in Cent der jeweiligen Whrung
		 * @param string $currency (default='EUR')  Whrung
		 * @param string $title (default='')  Bezeichnung der zu kaufenden Sache
		 * @param string $payText (default='')  Abbuchungstext der Lastschrift
		 * @param string $ip (default='')  IP des Benutzers
		 * @param array $freeParams (default=null)  Liste mit freien Parametern, die dem Vorgang zugeordnet werden
		 * @param string $mandateRef (default=null)  SEPA Mandats Referenz, wird ansonsten erzeugt
		 * @param string $mandateSignDate (default=null)  Datum der Mandatserteilung, ansonsten sessionApprove-Datum
		 * @param string $mandateRecur (default=null)  SEPA Mandat fr einzelne - Standard fr neue Mandate: "ONEOFF", oder wiederkehrende Zahlungen: "RECURRING" oder "FINAL"
		 * 
		 * @return array 
		 * @result string $sessionId eigene oder erzeugte eindeutige ID des Vorgangs
		 * @result string $status Vorgangsstatus "INIT" oder "REINIT"
		 * @result string $expire Ablaufzeit der Besttigung
		 * @result integer $amount bergebener Betrag bzw. Standard aus Konfiguration in Cent
		 * @result string $currency bergebene Whrung bzw. "EUR"
		 * @result string $title bergebene Kaufsache bzw. Standard aus Konfiguration
		 * @result string $payToken Zuordnungsschlssel im Lastschrifttext
		 * @result string $payText Abbuchungstext der Lastschrift
		 * @result string $payAmount Zahlbetrag in EUR-Cent
		 * @result string $creditorId SEPA Glubiger ID
		 * @result string $mandateRef SEPA Mandats Referenz
		 * @result string $mandateSignDate SEPA Datum der Mandatserteilung oder <leer>
		 * @result string $payRecurState SEPA Wiederholungs-Status der Zahlung: "OOFF", "FRST", "RCUR", "FNAL"
		 * @result string $payDate SEPA Datum der Belastung
		 */
		public function sessionCreate($accessKey, $testMode=0, $customerId, $sessionId='', $project, $projectCampaign='', $account='', $webmasterCampaign='', $amount=0, $currency='EUR', $title='', $payText='', $ip='', $freeParams=null, $mandateRef=null, $mandateSignDate=null, $mandateRecur=null);

		/**
		 * ordnet weitere freie Parameter der Session zu, oder ndert sie
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID des Vorgangs
		 * @param array $freeParams (default=null)  Liste mit zustzlichen freien Parametern
		 * 
		 * @return void 
		 */
		public function sessionSet($accessKey, $testMode=0, $sessionId, $freeParams=null);

		/**
		 * ermittelt Daten eines Bezahlvorgangs
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID des Vorgangs
		 * 
		 * @return array 
		 * @result string $status Vorgangsstatus "INIT", "REINIT", "APPROVED", "CHARGED", "REVERSED" oder "RECHARGED"
		 * @result string $expire Ablaufzeit bzw. Besttigung des Vorgangs
		 * @result string $statusDetail Beschreibung fr gescheiterte Transaktionen
		 * @result string $customerId ID des Kunden
		 * @result string $project zugeordnetes Projekt
		 * @result string $projectCampaign zugeordnete Projektkampagne
		 * @result string $account zugeordneter Webmasteraccount
		 * @result string $webmasterCampaign zugeordnete Webmasterkampagne
		 * @result integer $amount bergebener Betrag bzw. Standard aus Konfiguration in Cent
		 * @result string $currency bergebene Whrung bzw. "EUR"
		 * @result string $title bergebene Kaufsache bzw. Standard aus Konfiguration
		 * @result string $payToken Zuordnungsschlssel im Lastschrifttext
		 * @result string $payText Abbuchungstext der Lastschrift
		 * @result integer $payAmount Zahlbetrag in EUR-Cent
		 * @result integer $openAmount offener, noch zu zahlender Betrag der Session in EUR-Cent
		 * @result string $ip bergebene IP des Benutzers
		 * @result array $freeParams (default=null)  Liste mit allen freien Parametern
		 * @result string $creditorId SEPA Glubiger ID
		 * @result string $mandateRef SEPA Mandats Referenz
		 * @result string $mandateSignDate SEPA Datum der Mandatserteilung oder <leer>
		 * @result string $payRecurState SEPA Wiederholungs-Status der Zahlung: "OOFF", "FRST", "RCUR", "FNAL"
		 * @result string $payDate SEPA Datum der Belastung
		 */
		public function sessionGet($accessKey, $testMode=0, $sessionId);

		/**
		 * besttigt den Lastschrifteinzug eines Vorgangs
		 *  lst die Benachrichtigung sessionStatus mit dem Status "APPROVED" aus
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID des Vorgangs
		 * 
		 * @return array 
		 * @result string $status Vorgangsstatus "APPROVED" oder "FAILED"
		 * @result string $expire Zeitpunkt der Besttigung
		 */
		public function sessionApprove($accessKey, $testMode=0, $sessionId);

		/**
		 * ermittelt alle Bezahlvorgnge eines Kunden
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $customerId (default=null)  ID des Kunden
		 * 
		 * @return array 
		 * @result integer $count Anzahl der Eintrge in sessionIdList
		 * @result array $sessionIdList (default=null)  0-indizierte Liste mit Vorgang-IDs
		 */
		public function sessionList($accessKey, $testMode=0, $customerId=null);

		/**
		 * simuliert die Abbuchung fr alle besttigten Vorgnge
		 *  erzeugt fr jede besttigte Session eine neue Transaktion mit dem Typ "BOOKING" und lst die Benachrichtigung transactionCreate aus
		 *  lst die Benachrichtigung sessionStatus mit dem Status "CHARGED" aus
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  muss 1 sein
		 * 
		 * @return array 
		 * @result integer $count Anzahl der gebuchten Vorgnge
		 */
		public function sessionChargeTest($accessKey, $testMode=0);

		/**
		 * simuliert Stornierung eines einzelnen Vorgangs
		 *  erzeugt eine neue Transaktion mit dem Typ "REVERSAL" und lst die Benachrichtigung transactionCreate aus
		 *  lst die Benachrichtigung sessionStatus mit dem Status "REVERSED" aus
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  muss 1 sein
		 * @param string $sessionId ID des Vorgangs
		 * @param integer $reverseCode (default=0)  Textschlssel der Bank z.B. 9055 - Widerspruch
		 * @param string $reverseReason (default='UNKNOWN')  Rcklastschriftgrund "UNSPECIFIED", "ACCOUNT_EXPIRED", "ACCOUNT_WRONG", "NOT_AUTHORIZED", "CONTRADICTED", "UNKNOWN"
		 * 
		 * @return array 
		 * @result integer $amount stornierter Betrag inkl. Gebhr in EUR-Cent
		 */
		public function sessionReverseTest($accessKey, $testMode=0, $sessionId, $reverseCode=0, $reverseReason='UNKNOWN');

		/**
		 * simuliert die komplette Nachzahlung eines stornierten Vorgangs
		 *  erzeugt eine neue Transaktion mit dem Typ "BACKPAY" und lst die Benachrichtigung transactionCreate aus
		 *  lst die Benachrichtigung sessionStatus mit dem Status "RECHARGED" aus, wenn der gesamte offene Betrag beglichen wurde
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  muss 1 sein
		 * @param string $sessionId ID des Vorgangs
		 * @param integer $amount (default=null)  optional der nachgezahlte Teilbetrag in EUR-Cent
		 * 
		 * @return array 
		 * @result integer $amount gebuchter Betrag in EUR-Cent
		 */
		public function sessionRechargeTest($accessKey, $testMode=0, $sessionId, $amount=null);

		/**
		 * Veranlasst eine (Teil-)Gutschrift und berweist sie zurck
		 *  erzeugt eine neue Transaktion mit dem Typ "REFUND" und lst die Benachrichtigung transactionCreate aus
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID der zugehrigen Session
		 * @param string $bankCode (default=null)  Bankleitzahl, alternativ zur IBAN
		 * @param string $accountNumber (default=null)  Kontonummer, alternativ zur IBAN
		 * @param string $accountHolder (default=null)  Kontoinhaber
		 * @param integer $amount (default=null)  berweisungsbetrag in EUR-Cent, stdm. wird der gesamte eingegangene Betrag berwiesen
		 * @param string $payText (default=null)  Buchungstext, stdm. wird der ursprngliche Buchungstext verwendet
		 * @param string $iban (default=null)  IBAN des alternativen Empfngers
		 * @param string $bic (default=null)  BIC, opt. bei deutscher IBAN
		 * @param string $country (default='DE')  Sitz der Bank, alternativ zur IBAN
		 * 
		 * @return array 
		 * @result integer $amount berweisungsbetrag in EUR-Cent
		 * @result string $payText Buchungstext
		 */
		public function sessionRefund($accessKey, $testMode=0, $sessionId, $bankCode=null, $accountNumber=null, $accountHolder=null, $amount=null, $payText=null, $iban=null, $bic=null, $country='DE');

		/**
		 * simuliert Stornierung der letzten Gutschrift,
		 *  erzeugt eine neue Transaktion mit dem Typ "REFUNDREVERSAL" und lst die Benachrichtigung transactionCreate aus
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  muss 1 sein
		 * @param string $sessionId ID des Vorgangs
		 * 
		 * @return array 
		 * @result integer $amount stornierter Gutschriftbetrag in EUR-Cent
		 */
		public function sessionRefundReverseTest($accessKey, $testMode=0, $sessionId);

		/**
		 * erstellt eine Transaktion vom Typ "EXTERNAL"
		 *  lst die Benachrichtigung transactionCreate aus
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID der zugehrigen Session
		 * @param string $date (default=null)  Datum der Transaktion
		 * @param integer $amount Transaktionsbetrag in EUR-Cent
		 * @param string $description (default='""')  Beschreibungstext
		 * 
		 * @return void 
		 */
		public function transactionCreate($accessKey, $testMode=0, $sessionId, $date=null, $amount, $description='""');

		/**
		 * ermittelt alle Transaktionen fr einen Bezahlvorgang
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $sessionId ID des Vorgangs
		 * 
		 * @return array 
		 * @result integer $count Anzahl der Eintrge in transactionIdList
		 * @result array $transactionIdList 0-indizierte Liste mit Transaktions-IDs
		 */
		public function transactionList($accessKey, $testMode=0, $sessionId);

		/**
		 * ermittelt Daten einer Transaktion
		 *
		 * @param string $accessKey AccessKey aus dem Controlcenter
		 * @param integer $testMode (default=0)  aktiviert Testumgebung
		 * @param string $transactionId ID des Vorgangs
		 * 
		 * @return array 
		 * @result string $sessionId ID des Vorgangs
		 * @result string $date Datum der Transaktion
		 * @result string $type Art der Transaktion "BOOKING", "REVERSAL", "BACKPAY", "EXTERNAL", "REFUND", "REFUNDREVERSAL"
		 * @result string $reverseReason (default=null)  Bei $type = "REVERSAL" Art der Rcklastschrift "UNSPECIFIED", "ACCOUNT_EXPIRED", "ACCOUNT_WRONG", "NOT_AUTHORIZED", "CONTRADICTED", "UNKNOWN"
		 * @result integer $amount Transaktionsbetrag in EUR-Cent
		 * @result string $description Beschreibungstext
		 */
		public function transactionGet($accessKey, $testMode=0, $transactionId);

	}

?>